import { createReadStream } from "node:fs";
import { readdir } from "node:fs/promises";
import { exit } from "node:process";
import postImage from "./postImage.js";
import args from "./helpers/args.js";
import crashHandler from "./helpers/crashHandler.js";
export default async function getLocalImage(conf) {
    const sfw_files = await readdir(`${conf.directory}/sfw`).catch((e) => {
        crashHandler("Error reading SFW image directory.", e);
        return [];
    });
    const nsfw_files = await readdir(`${conf.directory}/nsfw`).catch((e) => {
        crashHandler("Error reading NSFW image directory.", e);
        return [];
    });
    const random = Math.floor(Math.random() * (sfw_files.length + nsfw_files.length));
    let image;
    let sensitivity;
    let file;
    if (random >= sfw_files.length) {
        file = `${conf.directory}/nsfw/${nsfw_files[random - sfw_files.length]}`;
        image = createReadStream(file).on("error", (err) => {
            crashHandler(`Error reading file "${file}"`, err);
        });
        sensitivity = true;
    }
    else {
        file = `${conf.directory}/sfw/${sfw_files[random]}`;
        image = createReadStream(file).on("error", (err) => {
            crashHandler(`Error reading file "${file}"`, err);
        });
        sensitivity = false;
    }
    if (args.verbose) {
        console.log(`File being sent: ${file}`);
        console.log(`Sensitivity: ${sensitivity}`);
    }
    await postImage(image, sensitivity, conf);
    exit(0);
}
//# sourceMappingURL=getLocalImage.js.map