import { createReadStream, createWriteStream } from "node:fs";
import { unlink } from "node:fs/promises";
import { exit } from "node:process";
import stream from "node:stream";
import { promisify } from "node:util";
import { search } from "booru";
import got from "got";
import postImage from "./postImage.js";
import args from "./helpers/args.js";
import crashHandler from "./helpers/crashHandler.js";
export default async function getRemoteImage(conf) {
    const searchResults = await search(conf.booru, conf.tags, {
        limit: 1,
        random: true,
    }).catch((e) => {
        crashHandler("Error searching for posts.", e);
        return [];
    });
    if (searchResults.length === 0) {
        crashHandler("Error searching for posts.", Error("No posts found."));
        return;
    }
    const post = searchResults[0];
    if (args.verbose)
        console.log(`Found post: ${post.id} at ${post.file_url}`);
    const sensitivity = post.rating !== "s";
    const filename = post.fileUrl?.split("/").pop();
    const pipeline = promisify(stream.pipeline);
    await pipeline(got.stream(post.file_url), createWriteStream(filename)).catch((err) => {
        crashHandler("Error saving downloading image.", err);
    });
    if (args.verbose)
        console.log(`Saved image to ${filename}`);
    const str = createReadStream(filename).on("error", (err) => {
        crashHandler("Error reading downloaded image.", err);
    });
    if (args.verbose) {
        console.log(`File being sent: ${filename}\nSensitivity: ${sensitivity}`);
    }
    await postImage(str, sensitivity, conf);
    await unlink(filename).catch((err) => {
        crashHandler("Error deleting downloaded image.", err);
    });
    if (args.verbose)
        console.log(`Successfully deleted image ${filename}`);
    exit(0);
}
//# sourceMappingURL=getRemoteImage.js.map