import { readFile } from "node:fs/promises";
import JSON5 from "json5";
import args from "./args.js";
import crashHandler from "./crashHandler.js";
async function readConfig() {
    return readFile(args.config, "utf8").catch((err) => {
        crashHandler("Error reading config file.", err);
        return "CRASH";
    });
}
export default async function getConfig() {
    let conf;
    try {
        conf = JSON5.parse(await readConfig().catch((err) => {
            crashHandler("Error reading config file.", err);
            return "";
        }));
        conf.retries ??= 5;
        if (conf.retries < 1)
            conf.retries = 1;
    }
    catch (err) {
        crashHandler("Error parsing config file.", Error(err));
        return {};
    }
    if (args.verbose) {
        console.log(`Read config file: ${args.config}\n${JSON.stringify(conf)}`);
    }
    return conf;
}
//# sourceMappingURL=getConfig.js.map